import { GetApiHandlers } from './routes/handlers';
import { CacheStore, GetIdFromResource, GetResource, CacheStoreData, Resource } from './store';
import { RouteMap } from './routes/routes.types';
import { NetworkClient } from './routes/networkClient';
export interface RestApiResource<ResourceType extends Resource, UserNetworkClient extends NetworkClient<any[]>, Routes extends RouteMap<ResourceType>> {
    subscribe: CacheStore<ResourceType>['subscribe'];
    unsubscribe: CacheStore<ResourceType>['unsubscribe'];
    getState: CacheStore<ResourceType>['getState'];
    forceUpdate: (data: any, config?: {
        transformData: (originalData: any) => ResourceType;
    }) => void;
    getApiHandlers: GetApiHandlers<ResourceType, UserNetworkClient, Routes>;
    getResource: GetResource<ResourceType>;
    getIdFromResource: GetIdFromResource<ResourceType>;
    clearStore: () => void;
    config: {
        routeConfig: Routes;
        store: CacheStore<ResourceType>;
        networkClient: UserNetworkClient;
        partialUpdate: boolean;
        transformData: (originalData: any) => ResourceType;
    };
}
export declare type ResourceConfig<ResourceType extends Resource> = {
    partialUpdate?: boolean;
    transformData?: (originalData: any) => ResourceType;
    customStore?: CacheStore<ResourceType>;
    initialData?: CacheStoreData<ResourceType>;
};
export declare function createResource<ResourceType extends Resource, UserNetworkClient extends NetworkClient<any> = NetworkClient<void[]>, ExtraRoutes extends RouteMap<any> = Record<string, any>>(resourceName: string, resourceUrl: string, networkClient: UserNetworkClient, extraRoutes?: ExtraRoutes, resourceConfig?: ResourceConfig<ResourceType>): RestApiResource<ResourceType, UserNetworkClient, {
    list: import("./routes/routes.types").RouteOptions<ResourceType, () => Record<any, string>, "list">;
    get: import("./routes/routes.types").RouteOptions<ResourceType, (id: ResourceType["id"]) => {
        resourceId: ResourceType["id"];
    }, "item">;
    put: import("./routes/routes.types").RouteOptions<ResourceType, (id: ResourceType["id"], data: ResourceType) => {
        resourceId: ResourceType["id"];
        body: ResourceType;
    }, "item">;
    patch: import("./routes/routes.types").RouteOptions<ResourceType, (id: ResourceType["id"], data: Partial<ResourceType>) => {
        resourceId: ResourceType["id"];
        body: Partial<ResourceType>;
    }, "item">;
    create: import("./routes/routes.types").RouteOptions<ResourceType, (data: import("./utils/types").Omit<ResourceType, "id">) => {
        body: import("./utils/types").Omit<ResourceType, "id">;
    }, "item">;
    remove: import("./routes/routes.types").RouteOptions<ResourceType, (id: ResourceType["id"]) => {
        resourceId: ResourceType["id"];
    }, "none">;
} & ExtraRoutes>;
