export declare type GetIdFromResource<ResourceType> = (data: ResourceType) => string;
export declare enum RouteMethod {
    get = "GET",
    post = "POST",
    put = "PUT",
    patch = "PATCH",
    delete = "DELETE"
}
export declare type RouteData<HttpClientOptions = any> = {
    resourceId?: any;
    body?: any;
    routeParams?: any[];
    queryParams?: Record<string, any>;
    config?: HttpClientOptions;
};
export interface RouteInheritableOptions<ResourceType> {
    entityUrl: string;
    transformData?: (originalData: any) => ResourceType;
}
export declare type RouteDataType = 'item' | 'list' | 'none';
export interface RouteOptions<ResourceType, TransformRequestFunc extends (...args: any) => RouteData = () => {}, DataType extends RouteDataType = 'item'> extends Partial<RouteInheritableOptions<ResourceType>> {
    handler?: TransformRequestFunc extends () => {} ? undefined : TransformRequestFunc;
    resource?: string;
    dataType?: DataType;
    transformResponse?: (response: any, requestData: RouteData) => DataType extends 'none' ? any : DataType extends 'list' ? ResourceType[] : ResourceType;
    method: RouteMethod;
}
export declare type RouteDataWithName = RouteOptions<any, any, any> & {
    name: string;
};
export declare type RouteMap<ResourceType> = {
    [K: string]: RouteOptions<ResourceType, any, any>;
};
export declare type Handlers<ResourceType, Routes extends RouteMap<ResourceType>> = {
    [P in keyof Routes]: (...params: Routes[P]['handler'] extends undefined ? [] : Parameters<NonNullable<Routes[P]['handler']>>) => Promise<ReturnType<NonNullable<Routes[P]['transformResponse']>>>;
};
