import { CacheStore, GetIdFromResource, Resource } from '../store';
import { RouteMap, RouteOptions, RouteDataWithName } from './routes.types';
import { NetworkClient } from './networkClient';
export declare type Handlers<ResourceType extends Resource, Routes extends RouteMap<ResourceType>> = {
    [P in keyof Routes]: (...params: Routes[P]['handler'] extends undefined ? [] : Parameters<NonNullable<Routes[P]['handler']>>) => Promise<NonNullable<Routes[P]['dataType']> extends 'none' ? any : NonNullable<Routes[P]['dataType']> extends 'list' ? ResourceType[] : ResourceType>;
};
export declare type GetApiHandlers<ResourceType extends Resource, UserNetworkClient extends NetworkClient<any>, Routes extends RouteMap<ResourceType>> = (...config: Parameters<UserNetworkClient>) => Handlers<ResourceType, Routes>;
export declare function checkIfValidId(storeName: string, id: string | number): boolean;
export declare function emitRequestAction<ResourceType extends Resource>(routeData: RouteDataWithName, { dataType }: RouteOptions<ResourceType, any, any>, { dispatch, actions: { update, updateList } }: CacheStore<ResourceType>): void;
export declare function emitDeleteAction<ResourceType extends Resource>(routeData: RouteDataWithName, { dispatch, actions: { deleteResource } }: CacheStore<ResourceType>): void;
export declare function transformResource<ResourceType extends Resource>(response: any, routeData: RouteDataWithName, { parseResponse, transformData }: RouteOptions<ResourceType, any, any>, { getStoreName }: CacheStore<ResourceType>, getIdFromResource: GetIdFromResource<ResourceType>): any;
export declare function emitUpdateItemAction<ResourceType extends Resource>(response: any, routeData: RouteDataWithName, routeConfig: RouteOptions<ResourceType, any, any>, store: CacheStore<ResourceType>, getIdFromResource: GetIdFromResource<ResourceType>): any;
export declare function emitUpdateListAction<ResourceType extends Resource>(response: any, routeData: RouteDataWithName, { parseResponse, ...routeConfig }: RouteOptions<ResourceType, any, any>, store: CacheStore<ResourceType>, getIdFromResource: GetIdFromResource<ResourceType>): ResourceType[] | undefined;
export declare function emitErrorAction<ResourceType extends Resource>(e: Error, routeData: RouteDataWithName, { dataType }: RouteOptions<ResourceType, any, any>, { dispatch, actions: { updateList, update } }: CacheStore<ResourceType>): void;
export declare function createHandlers<ResourceType extends Resource, UserNetworkClient extends NetworkClient<any>, Routes extends RouteMap<any>>(routes: Routes, store: CacheStore<ResourceType>, getIdFromResource: GetIdFromResource<ResourceType>, networkClient: UserNetworkClient): {
    getApiHandlers: GetApiHandlers<ResourceType, UserNetworkClient, Routes>;
};
